aboutsummaryrefslogtreecommitdiffstats
path: root/ports/linux/xattr/guts/setxattr.c
diff options
context:
space:
mode:
Diffstat (limited to 'ports/linux/xattr/guts/setxattr.c')
-rw-r--r--ports/linux/xattr/guts/setxattr.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/ports/linux/xattr/guts/setxattr.c b/ports/linux/xattr/guts/setxattr.c
index dd85252..bace0d8 100644
--- a/ports/linux/xattr/guts/setxattr.c
+++ b/ports/linux/xattr/guts/setxattr.c
@@ -2,10 +2,10 @@
* Copyright (c) 2014 Wind River Systems; see
* guts/COPYRIGHT for information.
*
* int setxattr(const char *path, const char *name, const void *value, size_t size, int flags)
* int rc = -1;
*/
- rc = shared_setxattr(path, -1, name, value, size, flags);
+ rc = shared_setxattr(path, -1, name, value, size, xflags);
/* return rc;
* }
@@ -2,10 +2,10 @@
* guts/COPYRIGHT for information.
*
- * int setxattr(const char *path, const char *name, const void *value, size_t size, int flags)
+ * int setxattr(const char *path, const char *name, const void *value, size_t size, int xflags)
* int rc = -1;
*/